%function [cftm, aftm] = LiuThorne()
clear all
tic;
  % get some numbers
  a = 17e-2;
  h = 20e-2;
  %r = 6e-2;
  w = 62000e-6;
  YS = 72e9; % Substrate Young's
  sigmaS = 0.17; % Substrate Poisson
  YC = 100e9; % Coating Young's
  sigmaC = 0.20; % Coating Poisson
  n = 1000; % number of points in integration and number of bessel zeros
  zeta = besselzero(1,n,1);
  r = linspace(0,a,n);
  d = 5.9e-6;
  
  % do the work
  
  [lambdaC,muC] = LambdaMu(YC,sigmaC);
  [lambdaS,muS] = LambdaMu(YS,sigmaS);
  
  j0m = besselj(0,zeta);
  r0 = w / sqrt(2);			% LT uses e-folding of power
  km = zeta/a;
  p0 = 1/(pi*a^2);			% LT 28
  pm = exp(-(km.^2*w^2/8))./(pi*a^2*j0m.^2);
  
  c0 = 6*a^2/h^2 * sum(j0m.*pm./zeta.^2);
  
  Qm = exp(-2*km*h);			% LT eq. 35a

  Am = pm*(lambdaS + 2*muS) ./ (km * muS*(lambdaS + muS)) .* ...
      (1 - Qm + 2*km*h.*Qm) ./ ((1-Qm).^2 - 4*km.^2*h^2.*Qm);
  
  Bm = pm*(lambdaS + 2*muS).*Qm ./ (km * muS*(lambdaS + muS)) .* ...
      (1 - Qm + 2*km*h)./((1-Qm).^2 - 4*km.^2*h^2.*Qm);
  
  Cm = -pm ./ (2*km * muS*(lambdaS + muS)) .*...
      ((2 * km.^2 * h^2 * (lambdaS + muS) + 2 * muS * km * h) .* Qm + muS*(1-Qm)) ./ ...
      ((1 - Qm).^2 - 4 * km.^2 * h^2 .* Qm);
  
  Dm = -(pm.*Qm) ./ (2*km * muS*(lambdaS + muS)) .*...
      (2 * km.^2 * h^2 * (lambdaS + muS) - 2 * muS * km * h - muS * (1-Qm)) ./ ...
      ((1 - Qm).^2 - 4 * km.^2 * h^2 .* Qm);
  
  
  Err = @(r) ...
      (sum(km.*(Cm + Dm)/2 .* (besselj(0,km*r) - besselj(2,km*r))) + ...
      ((lambdaS + 2*muS)*c0 + lambdaS*p0) / (2 * muS * (3*lambdaS + 2*muS)));
  
  Epp = @(r) ...
      (sum(km.*(Cm + Dm)/2 .* (besselj(0,km*r) + besselj(2,km*r))) + ...
      ((lambdaS + 2*muS)*c0 + lambdaS*p0) / (2 * muS * (3*lambdaS + 2*muS)));
  
  Ezz = @(r) ...
      (sum(-1/(lambdaC + 2*muC) * km.*besselj(0,km*r) .* ...
      (muS * (Am - Bm) + (lambdaC + 2*muS) * (Cm + Dm))) - ...
      (lambdaC * (lambdaS + 2*muS) * c0 + (lambdaS*lambdaC + 3*lambdaS*muS + 2*muS^2)* p0) / ...
      (muS * (3*lambdaS + 2*muS) * (lambdaC + 2*muC)));
  
  Trr = @(r) ...
      ((lambdaC + 2*muC)*Err(r) + lambdaC*(Epp(r) + Ezz(r)));
  
  Tpp = @(r) ...
      ((lambdaC + 2*muC)*Epp(r) + lambdaC*(Ezz(r) + Err(r)));
     
  Tzz = @(r) ...
      ((lambdaC + 2*muC)*Ezz(r) + lambdaC*(Err(r) + Epp(r)));
  
  %aftm = pi*d* integral(@(r) (Err(r) * Trr(r) + Epp(r) * Tpp(r) + Ezz(r) * Tzz(r)),...
  %    0,a)
  
  for i1 = 1:length(r)
      dU(i1) = r(i1)*(Err(r(i1)) * Trr(r(i1)) + Epp(r(i1)) * Tpp(r(i1)) + Ezz(r(i1)) * Tzz(r(i1)));
  end
  
  aftm = pi*d* trapz(r,dU)
  
  
  T = 300;
  kb = 1.3806488e-23;
  Omega = 2*pi*100;
  phi = 1e-4;
  
  S1 = 8*kb*T/Omega^2 * aftm * phi
  S2 = 4*kb*T/Omega^2 * d/(pi*w^2) *...
      (YC^2*(1+sigmaS)^2*(1-2*sigmaS)^2 + YS^2*(1+sigmaC)^2*(1-2*sigmaC))/...
      (YS^2*YC*(1-sigmaC^2)) * phi
  
  C = S1/S2
  
  toc
%end

% function [lambda,mu] = LambdaMu(Y,sigma)
% 
% lambda = Y*sigma/((1+sigma)*(1-2*sigma));
% 
% mu = Y/(2*(1+sigma));
% 
% end
